@@ -16,13 +16,19 @@ new_fv_profile <- function(bodymass,
                            F0_rel,
                            V0,
                            Pmax,
-                           Pmax_relative,
+                           Pmax_rel,
                            FV_slope,
                            RFmax_cutoff,
                            RFmax,
                            Drf,
                            RSE_FV,
                            RSE_Drf,
+                           F0_poly,
+                           F0_poly_rel,
+                           V0_poly,
+                           Pmax_poly,
+                           Pmax_poly_rel,
+                           FV_slope_poly,
                            data) {
   fv_profile <- list(
     bodymass = bodymass,
@@ -30,13 +36,19 @@ new_fv_profile <- function(bodymass,
     F0_rel = F0_rel,
     V0 = V0,
     Pmax = Pmax,
-    Pmax_relative = Pmax_relative,
+    Pmax_rel = Pmax_rel,
     FV_slope = FV_slope,
     RFmax_cutoff = RFmax_cutoff,
     RFmax = RFmax,
     Drf = Drf,
     RSE_FV = RSE_FV,
     RSE_Drf = RSE_Drf,
+    F0_poly = F0_poly,
+    F0_poly_rel = F0_poly_rel,
+    V0_poly = V0_poly,
+    Pmax_poly = Pmax_poly,
+    Pmax_poly_rel = Pmax_poly_rel,
+    FV_slope_poly = FV_slope_poly,
     data = data
   )
 
